@@ -13,7 +13,7 @@
 ##' @param trunc.prob Truncation probability 
 ##' @param same if 1 then left-truncation is same also for univariate truncation
 ##' @author Thomas Scheike and Klaus K. Holst
-##' @aliases simClaytonOakes
+##' @aliases simClaytonOakes simClaytonOakesLam
 ##' @export
 simClaytonOakes <- function(K,n,eta,beta,stoptime,lam=1,left=0,pairleft=0,trunc.prob=0.5,same=0)  ## {{{ 
 {
@@ -64,6 +64,24 @@ if (left>0) {
   return(ud)
 } ## }}} 
 
+##' @export
+simClaytonOakesLam <- function(n,k,cumhaz,vargam,entry=NULL)  
+{ ## {{{ 
+base1 <- cumhaz
+dtt <- diff(c(0,base1[,1]))
+lams <- (diff(c(0,base1[,2]))/dtt)*exp(vargam*base1[,2])
+Lams <- cbind(base1[,1],cumsum(dtt*lams))
+
+if (is.null(entry)) entry <- rep(0,n*k)
+gamma <- rep(rgamma(n,1/vargam)*vargam,each=k)
+ddd <- pc.hazard(rbind(c(0,0),Lams),rr=gamma,entry=entry)
+ddd$cluster <- rep(1:n,each=k)
+ddd$gamma <- gamma
+
+attr(ddd,"cumhaz") <- Lams
+return(ddd)
+} ## }}} 
+
 ##' Simulate observations from the Clayton-Oakes copula model with
 ##' Weibull type baseline and Cox marginals.
 ##'
@@ -234,7 +252,6 @@ names(ud)<-c("time","status","x","cluster","type","mintime","lefttime","truncate
 return(ud)
 } ## }}} 
 
-
 ##' @export
 simCompete.twin.ace <- function(K,varg,varc,beta,stoptime,lam0=c(0.2,0.3),
 		Cvar=0,left=0,pairleft=0,trunc.prob=0.5,overall=1,all.sum=1)  ## {{{ 
@@ -531,7 +548,7 @@ return(ud)
 } ## }}} 
 
 ##' @export
-kendall.ClaytonOakes.twin.ace <- function(parg,parc,K=10000)  ## {{{ 
+kendall.ClaytonOakes.twin.ace <- function(parg,parc,K=10000,test=0)  ## {{{ 
 { 
   ## K antal clustre, n=antal i clustre
   ### total variance of gene and env. 
@@ -553,6 +570,14 @@ kendall.ClaytonOakes.twin.ace <- function(parg,parc,K=10000)  ## {{{
   dzrv1 <- Gams1[,2]+Gams1[,3]+Gams1[,5] ### 0.5 shared gene + 0.5 non-shared + env 
   dzrv2 <- Gams1[,2]+Gams1[,4]+Gams1[,5] ### 0.5 shared gene + 0.5 non-shared + env 
   Gam1 <- cbind(mz*mzrv+dz*dzrv1,mz*mzrv+dz*dzrv2)
+  if (test==1) {
+	  cat("mz cor")
+	  print(apply(Gam1[mz==1,1:2],2,var))
+	  print(cor(Gam1[mz==1,1:2]))
+	  cat("dz cor")
+	  print(apply(Gam1[mz==0,1:2],2,var))
+	  print(cor(Gam1[mz==0,1:2]))
+  }
   Gam1 <- data.frame(cbind(Gam1,mz,id))
 
   ## Silence false R CMD CHECK warnings:
